<template>
  <div>
    <div>
      <div class="view-title">
        <span>量值溯源计划</span>
        <span>
          <el-button size="medium" @click="exportFun">导 出</el-button>
          <el-button size="medium" @click="uploadDia = true">导 入</el-button>
          <el-button size="medium" type="primary" @click="openFormDia('add')">新 增</el-button>
        </span>
      </div>
      <div class="search-background">
        <span class="search-group">
          <span style="width: 120px">仪器名称：</span>
          <el-input v-model="searchForm.instrumentName" clearable size="small"></el-input>
        </span>
        <span class="search-group">
          <span style="width: 120px">管理编号：</span>
          <el-input v-model="searchForm.managementNumber" clearable size="small"></el-input>
        </span>
        <span class="search-group">
          <el-button size="medium"  @click="resetSearchForm">重 置</el-button>
          <el-button size="medium" type="primary" @click="searchList">查 询</el-button>
        </span>
      </div>
      <div class="table">
        <div>
          <TableCard :showForm="false" :showTitle="false">
            <template v-slot:table>
              <ZTTable
                :column="tableColumn"
                :height="'calc(100vh - 23em)'"
                :table-data="tableData"
                :table-loading="tableLoading"
                style="padding: 0 15px;margin-bottom: 16px">
              </ZTTable>
            </template>
          </TableCard>
          <el-pagination :current-page="1" :page-size="page.size" :page-sizes="[10, 20, 30, 50, 100]"
                         :total="total" layout="->,total, sizes, prev, pager, next, jumper"
                         @size-change="handleSizeChange"
                         @current-change="handleCurrentChange">
          </el-pagination>
        </div>
      </div>
    </div>
    <form-dia v-if="formDia" ref="formDia" @closeFormDia="closeFormDia"></form-dia>
    <el-dialog :visible.sync="uploadDia" title="数据导入" width="500px">
      <div style="margin: 0 auto;">
        <el-upload ref="upload" :action="javaApi + $api.feCalibrationSchedule.importOfValueTraceabilityPlan" :auto-upload="false" :before-upload="beforeUpload" :file-list="fileList" :headers="token"
                   :limit="1" :on-error="onError" :on-success="onSuccess" accept=".xlsx" drag
                   name="file">
          <i class="el-icon-upload"></i>
          <div class="el-upload__text">将文件拖到此处，或<em>点击上传</em></div>
        </el-upload>
      </div>
      <span slot="footer" class="dialog-footer">
        <el-button @click="uploadDia = false">取 消</el-button>
        <el-button :loading="uploading" type="primary" @click="submitUpload()">上 传</el-button>
      </span>
    </el-dialog >
  </div>
</template>

<script>
import TableCard from '../caorui/TableCard/index.vue';
import ZTTable from '../caorui/ZTTable/index.vue';
import FormDia from '../do/a6-quantity-value-traceability-plan/formDia.vue';

export default {
  name: 'a6-quantity-value-traceability-plan',
  // import 引入的组件需要注入到对象中才能使用
  components: { FormDia, ZTTable, TableCard },
  data() {
    // 这里存放数据
    return {
      outLoading: false,
      searchForm: {
        instrumentName: '',
        managementNumber: '',
      },
      tableColumn: [
        {
          label: '仪器名称',
          prop: 'instrumentName',
          minWidth: '120'
        },
        {
          label: '规格型号',
          prop: 'model',
          minWidth: '100'
        },
        {
          label: '管理编号',
          prop: 'managementNumber',
          minWidth: '100'
        },
        {
          label: '技术指标',
          prop: 'technicalIndicators',
          minWidth: '100'
        },
        {
          label: '检定周期',
          prop: 'verificationCyde',
          minWidth: '100'
        },
        {
          label: '检定单位',
          prop: 'verificationUnit',
          minWidth: '100'
        },
        {
          label: '最近检定日期',
          prop: 'recentlyTime',
          minWidth: '100'
        },
        {
          label: '计划下次检定日期',
          prop: 'nextTime',
          minWidth: '100'
        },
        {
          label: '备注',
          prop: 'remark',
          minWidth: '100'
        },
        {
          dataType: 'action',
          fixed: 'right',
          minWidth: '180',
          label: '操作',
          operation: [
            {
              name: '编辑',
              type: 'text',
              clickFun: (row) => {
                this.openFormDia('edit', row);
              },
            },
            {
              name: '删除',
              type: 'text',
              color: '#f56c6c',
              clickFun: (row) => {
                this.delPlan(row)
              },
            }
          ]
        }
      ],
      tableData: [],
      tableLoading: false,
      uploadDia: false,
      uploading: false,
      page: {
        size: 20,
        current: 1,
      },
      total: 0,
      formDia: false,
      fileList: [],
      token: ""
    };
  },
  mounted() {
    this.token = {
      'token': sessionStorage.getItem('token')
    }
    this.searchList()
  },
  // 方法集合
  methods: {
    beforeUpload(file, fileList) {
      if (file.type != 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet') {
        this.$message.error('上传文件格式不正确');
        this.$refs.upload.clearFiles()
        return false;
      }
    },
    submitUpload() {
      if (this.$refs.upload.uploadFiles.length == 0) {
        this.$message.error('未选择文件')
        return
      }
      this.uploading = true
      this.$refs.upload.submit();
      this.uploading = false
    },
    onError(err, file, fileList) {
      this.$message.error('上传失败')
      this.$refs.upload.clearFiles()
      this.uploading = false
    },
    onSuccess(response, file, fileList) {
      this.$refs.upload.clearFiles()
      this.uploadDia = false
      this.uploading = false
      if (response.code == 201) {
        this.$message.error(response.message)
        return
      }
      this.$message.success('上传成功')
      this.standardList = []
      this.productList = []
      this.searchList()
    },
    // 导出
    exportFun() {
      this.outLoading = true
      this.$axios.post(this.$api.feCalibrationSchedule.exportOfValueTraceabilityPlan, {
        instrumentName: this.searchForm.instrumentName
      }, {responseType: "blob"}).then(res => {
        this.outLoading = false
        this.$message.success('导出成功')
        const blob = new Blob([res], {type: 'application/octet-stream'});
        const url = URL.createObjectURL(blob);
        const link = document.createElement('a');
        link.href = url;
        link.download = '量值溯源计划.xlsx';
        link.click();
      }).finally(() => {
        this.outLoading = false
      })
    },
    // 查询列表
    searchList () {
      this.tableLoading = true
      this.$axios.get(this.$api.feCalibrationSchedule.getPageCalibrationSchedule + '?instrumentName=' + this.searchForm.instrumentName
        + '&managementNumber=' + this.searchForm.managementNumber
        + '&pages=' + this.page.current + '&size=' + this.page.size).then(res => {
        this.tableLoading = false
        if (res.code === 201) return
        this.tableData = res.data.records
        this.total = res.data.total
      }).catch(err => {
        console.log('err---', err);
        this.tableLoading = false
      })
    },
    // 删除
    delPlan (row) {
      this.$confirm('此操作将永久删除该数据, 是否继续?', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(() => {
        this.tableLoading = true
        this.$axios.get(this.$api.feCalibrationSchedule.removeCalibrationSchedule + '?id=' + row.id).then(res => {
          this.tableLoading = false
          if (res.code === 201) return
          this.$message.success('删除成功')
          this.searchList()
        }).catch(err => {
          this.tableLoading = false
          console.log('err---', err);
        })
      }).catch(() => {
        this.$message({
          type: 'info',
          message: '已取消删除'
        });
      });
    },
    // 重置查询条件
    resetSearchForm () {
      this.searchForm.instrumentName = '';
      this.searchForm.managementNumber = '';
      this.searchList()
    },
    // 新增，编辑，批准弹框
    openFormDia (type, row) {
      this.formDia = true
      this.$nextTick(() => {
        this.$refs.formDia.openDia(type, row)
      })
    },
    closeFormDia () {
      this.formDia = false
      this.searchList()
    },
    // 分页
    handleSizeChange(val) {
      this.page.size = val;
      this.searchList();
    },
    handleCurrentChange(val) {
      this.page.current = val;
      this.searchList();
    },
  }
};
</script>

<style scoped>
.view-title {
  display: flex;
  justify-content: space-between;
  align-items: center;
  height: 60px;
  padding-left: 20px;
}

.search-background {
  width: 100%;
  height: 80px;
  line-height: 80px;
  background-color: #ffffff;
  display: flex;
}

.search-group {
  display: flex;
  align-items: center;
  margin: 0 20px;
}

.table {
  margin-top: 20px;
  background-color: #ffffff;
  padding-top: 20px;
}
</style>
